@@ -352,6 +352,7 @@ smart_hux_from_df <- function(dfr) {
 #' @param x A huxtable.
 #' @param ... Options passed to other methods.
 #'
+#' @return `print` prints the huxtable and returns `NULL` invisibly.
 #' @export
 #'
 #' @examples
@@ -369,6 +370,24 @@ print.huxtable <- function(x, ...) {
 }
 
 
+#' @rdname print.huxtable
+#' @param output One of `"html"`, `"latex"`, `"md"` or `"screen"`
+#'
+#' @return `format` returns a string representation from [to_latex()], [to_html()] etc.
+#' @export
+#'
+#' @examples
+#' ht <- hux(a = 1:3, b = 4:6)
+#' format(ht, output = 'screen')
+#' format(ht, output = 'md')
+format.huxtable <- function(x, ..., output) {
+  assert_that(is.string(output))
+  assert_that(output %in% c('latex', 'html', 'md', 'screen'))
+  fn <- paste0('to_', output)
+  do.call(fn, list(ht = x, ...))
+}
+
+
 #' Guess knitr output format
 #'
 #' Convenience function which tries to guess the ultimate output from knitr and rmarkdown.
@@ -529,7 +548,7 @@ hux_logo <- function(latex = FALSE) {
   text_color(logo)[1, 3] <- 'white'
   width(logo) <- if (latex) '0.21\\textwidth' else '60pt'
   height(logo) <- if (latex) '45pt' else '60pt'
-  font(logo) <- 'Palatino, Palatino Linotype, Palatino LT STD, Book Antiqua, Georgia, serif'
+  font(logo) <- 'Palatino'
   if (latex) font(logo) <- 'ppl'
   top_padding(logo) <- 2
   bottom_padding(logo) <- 2
